/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
package org.elasticsearch.xpack.ccr.rest;

import org.elasticsearch.client.node.NodeClient;
import org.elasticsearch.common.xcontent.XContentParser;
import org.elasticsearch.rest.BaseRestHandler;
import org.elasticsearch.rest.RestController;
import org.elasticsearch.rest.RestRequest;
import org.elasticsearch.rest.action.RestToXContentListener;
import org.elasticsearch.xpack.core.ccr.action.PutAutoFollowPatternAction.Request;

import java.io.IOException;

import static org.elasticsearch.xpack.core.ccr.action.PutAutoFollowPatternAction.INSTANCE;

public class RestPutAutoFollowPatternAction extends BaseRestHandler {

    public RestPutAutoFollowPatternAction(RestController controller) {
        controller.registerHandler(RestRequest.Method.PUT, "/_ccr/auto_follow/{name}", this);
    }

    @Override
    public String getName() {
        return "ccr_put_auto_follow_pattern_action";
    }

    @Override
    protected RestChannelConsumer prepareRequest(RestRequest restRequest, NodeClient client) throws IOException {
        Request request = createRequest(restRequest);
        return channel -> client.execute(INSTANCE, request, new RestToXContentListener<>(channel));
    }

    private static Request createRequest(RestRequest restRequest) throws IOException {
        try (XContentParser parser = restRequest.contentOrSourceParamParser()) {
            return Request.fromXContent(parser, restRequest.param("name"));
        }
    }
}
